Interface FluentSynchronizerApi.Void

All Superinterfaces:
FluentSynchronizerApi.Common
All Known Subinterfaces:
FluentSynchronizerApi.VoidInvoke
Enclosing interface:
FluentSynchronizerApi

public static interface FluentSynchronizerApi.Void extends FluentSynchronizerApi.Common
  • Method Details

    • run

      Adds an action to the chain that calls the given Runnable.
      Parameters:
      runnable - the runnable to call
      Throws:
      NullPointerException - if runnable is null
    • get

      <T extends @Nullable Object> FluentSynchronizerApi.Value<T> get(Supplier<T> supplier)
      Adds an action to the chain that calls the given Supplier.

      The value returned by the supplier is kept as the chain result and will be returned by the chain invocation. Intermediate actions can be used to transform or discard the chain result.

      Parameters:
      supplier - the supplier to call
      Throws:
      NullPointerException - if supplier is null
    • sleepUntil

      Description copied from interface: FluentSynchronizerApi.Common
      Adds sleeping to the action chain.

      This action ensures the given condition is met before performing the next action. When this action begins, the supplier is called immediately.

      Supplier returns false:
      The chain sleeps until another chain wakes it up. The supplier is then called again and if it still returns false, the chain resumes sleeping.
      Supplier returns true:
      The chain proceeds to perform the next action.
      Specified by:
      sleepUntil in interface FluentSynchronizerApi.Common
      Parameters:
      state - the supplier that returns true if the action chain should proceed to the next action, false otherwise.
    • sleepUntil

      FluentSynchronizerApi.VoidInvoke sleepUntil(BooleanSupplier state, Duration checkInterval)
      Description copied from interface: FluentSynchronizerApi.Common
      Adds sleeping to the action chain.

      This action ensures the given condition is met before performing the next action. When this action begins, the supplier is called immediately.

      Supplier returns false:
      The chain sleeps until either another chain wakes it up or the checkInterval has passed.

      In both cases, the supplier is then called again and if it still returns false, the chain resumes sleeping.

      Supplier returns true:
      The chain proceeds to perform the next action.
      Specified by:
      sleepUntil in interface FluentSynchronizerApi.Common
      Parameters:
      state - the supplier that returns true if the action chain should proceed to the next action, false otherwise.
      checkInterval - how often the condition should be re-checked even if no wake call happens, or null for "never".
    • wakeOthers

      Description copied from interface: FluentSynchronizerApi.Common
      Adds an action which wakes other chains.
      Specified by:
      wakeOthers in interface FluentSynchronizerApi.Common