Package com.github.mizool.core.concurrent
package com.github.mizool.core.concurrent
-
ClassDescriptionBuffers a stream of futures and provides the results as a new stream.Encapsulates synchronization and wait/notify functionality.Provides the syntax for
FluentSynchronizer.FluentSynchronizerApi.Value<T extends @Nullable Object>Joins a stream of futures, returning a single joint future.Provides fluent syntax for joining completable futures.Provides fluent syntax for joiningListenableFutures.Lazy<T>A value container where the value is lazily obtained from the givenSupplieron the firstLazy.get()call.Deprecated, for removal: This API element is subject to removal in a future version.This class does not offer enough flexibility and will be removed.Provides fluent syntax forSynchronizer.