Class Config

java.lang.Object
com.github.mizool.core.configuration.Config

public final class Config extends Object
Main entry point for the configuration API.
  • Method Details

    • from

      public static RootNode from(Source source)
      Creates a root node encapsulating access to the given Source instance.
    • systemProperties

      public static RootNode systemProperties()
      Creates a root node encapsulating access to the current system properties.
    • from

      public static RootNode from(Properties properties)
      Creates a root node encapsulating access to the given Properties instance.
    • from

      public static RootNode from(Reader reader)
      Consumes the given reader and returns a root node encapsulating access to its properties.
    • from

      public static RootNode from(InputStream inputStream, Charset charset)
      Consumes the input stream and returns a root node encapsulating access to its properties.
      Parameters:
      inputStream - the input stream to load from
      charset - the charset to use