Class RootNode

java.lang.Object
com.github.mizool.core.configuration.RootNode
All Implemented Interfaces:
HasChildren

public final class RootNode extends Object implements HasChildren
The root node of a set of properties.
  • Method Details

    • child

      public PropertyNode child(String key)
      Description copied from interface: HasChildren
      Returns the child PropertyNode with the given name. Until a value is retrieved, no check is made for the existence of any property.

      Example: For a node representing timeouts.network, calling child("connect") will return a node representing timeouts.network.connect.
      Specified by:
      child in interface HasChildren
      Parameters:
      key - one or more segments of the key to append to the key of the current node
      Returns:
      the child or descendant node, never null.
    • toString

      public String toString()
      Overrides:
      toString in class Object