Skip navigation links
  • Overview
  • Package
  • Class
  • Use
  • Tree
  • Deprecated
  • Index
  • Help

Deprecated API

Contents

  • Terminally Deprecated
  • Classes
  • Methods
  • Constructors
  • Terminally Deprecated Elements
    Element
    Description
    com.github.mizool.core.concurrent.Synchronizer
    This class does not offer enough flexibility and will be removed. Use FluentSynchronizer instead.
    com.github.mizool.core.configuration.Config.blank()
    Use Sources.blank() instead.
    com.github.mizool.core.configuration.RootNode.add(InputStream, Charset)
    Use Sources.join(Source, Source) together with Sources.from(InputStream, Charset) instead
    com.github.mizool.core.configuration.RootNode.add(Reader)
    Use Sources.join(Source, Source) together with Sources.from(Properties) instead
    com.github.mizool.core.MetaInfServices.instances(Class<S>)
    When it was introduced years ago, the point of this method was to ensure the ServiceLoader call always used the classloader of the service class. At the time, this seemed to be important, even essential, so it was decided to ensure this "correct" usage.

    Fast-forward to 2025, this turned out to be harmful: in environments with layered classloaders like Quarkus, this limits the returned service implementations to those from library jars and omits those supplied by the application.

    For this reason, this method now uses the current thread's context classloader. Consequently, calling it is now equivalent to calling ServiceLoader.load(Class). Calls should therefore be replaced as this method is going to be removed.

  • Deprecated Classes
    Class
    Description
    com.github.mizool.core.concurrent.Synchronizer
    This class does not offer enough flexibility and will be removed. Use FluentSynchronizer instead.
    com.github.mizool.core.password.Pbkdf2WithHmacSha1Hasher
    For newly saved passwords, use Pbkdf2WithHmacSha512Hasher instead. This hasher is kept to allow continued verification of old passwords.
  • Deprecated Methods
    Method
    Description
    com.github.mizool.core.configuration.Config.blank()
    Use Sources.blank() instead.
    com.github.mizool.core.configuration.RootNode.add(InputStream, Charset)
    Use Sources.join(Source, Source) together with Sources.from(InputStream, Charset) instead
    com.github.mizool.core.configuration.RootNode.add(Reader)
    Use Sources.join(Source, Source) together with Sources.from(Properties) instead
    com.github.mizool.core.MetaInfServices.instances(Class<S>)
    When it was introduced years ago, the point of this method was to ensure the ServiceLoader call always used the classloader of the service class. At the time, this seemed to be important, even essential, so it was decided to ensure this "correct" usage.

    Fast-forward to 2025, this turned out to be harmful: in environments with layered classloaders like Quarkus, this limits the returned service implementations to those from library jars and omits those supplied by the application.

    For this reason, this method now uses the current thread's context classloader. Consequently, calling it is now equivalent to calling ServiceLoader.load(Class). Calls should therefore be replaced as this method is going to be removed.

  • Deprecated Constructors
    Constructor
    Description
    com.github.mizool.core.exception.NotYetImplementedException()
    Deprecated to remind you to implement the corresponding code before releasing the software.
    com.github.mizool.core.exception.NotYetImplementedException(String)
    Deprecated to remind you to implement the corresponding code before releasing the software.

Copyright © 2026. All rights reserved.