Interface FluentSynchronizerApi.Common
- All Known Subinterfaces:
FluentSynchronizerApi.Value<T>,FluentSynchronizerApi.Void,FluentSynchronizerApi.VoidInvoke
- Enclosing interface:
- FluentSynchronizerApi
@CheckReturnValue
public static interface FluentSynchronizerApi.Common
-
Method Summary
Modifier and TypeMethodDescriptionsleepUntil(BooleanSupplier state) Adds sleeping to the action chain.sleepUntil(BooleanSupplier state, Duration checkInterval) Adds sleeping to the action chain.Adds an action which wakes other chains.
-
Method Details
-
sleepUntil
Adds sleeping to the action chain.This action ensures the given condition is met before performing the next action. When this action begins, the supplier is called immediately.
- Supplier returns
false: -
The chain sleeps until another chain wakes it up. The supplier is then called again and if it still
returns
false, the chain resumes sleeping. - Supplier returns
true: - The chain proceeds to perform the next action.
- Parameters:
state- the supplier that returnstrueif the action chain should proceed to the next action,falseotherwise.- Throws:
NullPointerException- ifstateis null
- Supplier returns
-
sleepUntil
Adds sleeping to the action chain.This action ensures the given condition is met before performing the next action. When this action begins, the supplier is called immediately.
- Supplier returns
false: -
The chain sleeps until either another chain wakes it up or the
checkIntervalhas passed.In both cases, the supplier is then called again and if it still returns
false, the chain resumes sleeping. - Supplier returns
true: - The chain proceeds to perform the next action.
- Parameters:
state- the supplier that returnstrueif the action chain should proceed to the next action,falseotherwise.checkInterval- how often the condition should be re-checked even if no wake call happens, ornullfor "never".- Throws:
NullPointerException- ifstateis null
- Supplier returns
-
wakeOthers
Object wakeOthers()Adds an action which wakes other chains.
-