Class Config
java.lang.Object
com.github.mizool.core.configuration.Config
Main entry point for the configuration API.
-
Method Summary
Modifier and TypeMethodDescriptionstatic RootNodeCreates a root node encapsulating access to the givenSourceinstance.static RootNodefrom(InputStream inputStream, Charset charset) Consumes the input stream and returns a root node encapsulating access to its properties.static RootNodeConsumes the given reader and returns a root node encapsulating access to its properties.static RootNodefrom(Properties properties) Creates a root node encapsulating access to the givenPropertiesinstance.static RootNodeCreates a root node encapsulating access to the current system properties.
-
Method Details
-
from
Creates a root node encapsulating access to the givenSourceinstance. -
systemProperties
Creates a root node encapsulating access to the current system properties. -
from
Creates a root node encapsulating access to the givenPropertiesinstance. -
from
Consumes the given reader and returns a root node encapsulating access to its properties. -
from
Consumes the input stream and returns a root node encapsulating access to its properties.- Parameters:
inputStream- the input stream to load fromcharset- the charset to use
-