Class RootNode
java.lang.Object
com.github.mizool.core.configuration.RootNode
- All Implemented Interfaces:
HasChildren
The root node of a set of properties.
-
Method Summary
-
Method Details
-
child
Description copied from interface:HasChildrenReturns the childPropertyNodewith the given name. Until a value is retrieved, no check is made for the existence of any property.
Example: For a node representingtimeouts.network, callingchild("connect")will return a node representingtimeouts.network.connect.- Specified by:
childin interfaceHasChildren- Parameters:
key- one or more segments of the key to append to the key of the current node- Returns:
- the child or descendant node, never
null.
-
toString
-