Class RootNode

java.lang.Object
com.github.mizool.core.configuration.RootNode
All Implemented Interfaces:
HasChildren

public final class RootNode extends Object implements HasChildren
The root node of a set of properties.
  • Method Details

    • child

      public PropertyNode child(String key)
      Description copied from interface: HasChildren
      Returns the child PropertyNode with the given name. Until a value is retrieved, no check is made for the existence of any property.

      Example: For a node representing timeouts.network, calling child("connect") will return a node representing timeouts.network.connect.
      Specified by:
      child in interface HasChildren
      Parameters:
      key - one or more segments of the key to append to the key of the current node
      Returns:
      the child or descendant node, never null.
    • add

      @Deprecated(since="8.3", forRemoval=true) public RootNode add(Reader reader)
      Deprecated, for removal: This API element is subject to removal in a future version.
      Creates a new root node that incorporates the current node's properties and the ones loaded from the given reader. For keys present in both sets of data, the ones from reader take precedence.
      Parameters:
      reader - the reader to load from
      Throws:
      UncheckedIOException - if reading failed
    • add

      @Deprecated(since="8.3", forRemoval=true) public RootNode add(InputStream inputStream, Charset charset)
      Deprecated, for removal: This API element is subject to removal in a future version.
      Creates a new root node that incorporates the current node's properties and the ones loaded from the given input stream. For keys present in both sets of data, the ones from inputStream take precedence.
      Parameters:
      inputStream - the input stream to load from
      charset - the charset to use
      Throws:
      UncheckedIOException - if reading failed
    • toString

      public String toString()
      Overrides:
      toString in class Object